@@ -11,7 +11,7 @@
 #include <kdev-pg-list.h>
 
 
-# 58 "/builds/chakra/packages/desktop/kdev-php/src/kdev-php-5.4.5/parser/php.g" 1
+# 58 "/chakra/desktop/kdev-php/src/kdev-php-5.5.2/parser/php.g" 1
 
 
 #include <QtCore/QRegularExpression>
@@ -26,7 +26,7 @@ namespace Php
 {
 
 
-# 92 "/builds/chakra/packages/desktop/kdev-php/src/kdev-php-5.4.5/parser/php.g" 1
+# 92 "/chakra/desktop/kdev-php/src/kdev-php-5.5.2/parser/php.g" 1
 
 class Lexer;
 
@@ -178,46 +178,49 @@ struct KDEVPHPPARSER_EXPORT AstNode
         ParameterTypeKind = 1089,
         PostprefixOperatorKind = 1090,
         PrintExpressionKind = 1091,
-        RelationalExpressionKind = 1092,
-        RelationalExpressionRestKind = 1093,
-        ReservedNonModifierIdentifierKind = 1094,
-        ReservedNonModifiersKind = 1095,
-        ReturnTypeKind = 1096,
-        ScalarKind = 1097,
-        SemiReservedKind = 1098,
-        SemiReservedIdentifierKind = 1099,
-        SemicolonOrCloseTagKind = 1100,
-        ShiftExpressionKind = 1101,
-        ShiftExpressionRestKind = 1102,
-        StartKind = 1103,
-        StatementKind = 1104,
-        StaticArrayPairValueKind = 1105,
-        StaticMemberKind = 1106,
-        StaticPropertyKind = 1107,
-        StaticScalarKind = 1108,
-        StaticVarKind = 1109,
-        StringIndexSpecifierKind = 1110,
-        SwitchCaseListKind = 1111,
-        TopStatementKind = 1112,
-        TraitAliasDeclarationKind = 1113,
-        TraitAliasIdentifierKind = 1114,
-        TraitAliasStatementKind = 1115,
-        TraitDeclarationStatementKind = 1116,
-        TraitVisibilityModifiersKind = 1117,
-        UnaryExpressionKind = 1118,
-        UnaryExpressionNotPlusminusKind = 1119,
-        UseNamespaceKind = 1120,
-        VarExpressionKind = 1121,
-        VarExpressionArrayKind = 1122,
-        VarExpressionNewObjectKind = 1123,
-        VarExpressionNormalKind = 1124,
-        VariableKind = 1125,
-        VariableIdentifierKind = 1126,
-        VariableNameKind = 1127,
-        VariableObjectPropertyKind = 1128,
-        VariablePropertyKind = 1129,
-        VariableWithoutObjectsKind = 1130,
-        WhileStatementKind = 1131,
+        PropertyTypeKind = 1092,
+        PropertyTypeHintKind = 1093,
+        RelationalExpressionKind = 1094,
+        RelationalExpressionRestKind = 1095,
+        ReservedNonModifierIdentifierKind = 1096,
+        ReservedNonModifiersKind = 1097,
+        ReturnTypeKind = 1098,
+        ScalarKind = 1099,
+        SemiReservedKind = 1100,
+        SemiReservedIdentifierKind = 1101,
+        SemicolonOrCloseTagKind = 1102,
+        ShiftExpressionKind = 1103,
+        ShiftExpressionRestKind = 1104,
+        StartKind = 1105,
+        StatementKind = 1106,
+        StaticArrayPairValueKind = 1107,
+        StaticMemberKind = 1108,
+        StaticPropertyKind = 1109,
+        StaticScalarKind = 1110,
+        StaticVarKind = 1111,
+        StringIndexSpecifierKind = 1112,
+        SwitchCaseListKind = 1113,
+        TopStatementKind = 1114,
+        TraitAliasDeclarationKind = 1115,
+        TraitAliasIdentifierKind = 1116,
+        TraitAliasStatementKind = 1117,
+        TraitDeclarationStatementKind = 1118,
+        TraitVisibilityModifiersKind = 1119,
+        UnaryExpressionKind = 1120,
+        UnaryExpressionNotPlusminusKind = 1121,
+        UseNamespaceKind = 1122,
+        UseStatementKind = 1123,
+        VarExpressionKind = 1124,
+        VarExpressionArrayKind = 1125,
+        VarExpressionNewObjectKind = 1126,
+        VarExpressionNormalKind = 1127,
+        VariableKind = 1128,
+        VariableIdentifierKind = 1129,
+        VariableNameKind = 1130,
+        VariableObjectPropertyKind = 1131,
+        VariablePropertyKind = 1132,
+        VariableWithoutObjectsKind = 1133,
+        WhileStatementKind = 1134,
         AST_NODE_KIND_COUNT
     };
 
@@ -225,7 +228,7 @@ struct KDEVPHPPARSER_EXPORT AstNode
     qint64 startToken;
     qint64 endToken;
 
-# 147 "/builds/chakra/packages/desktop/kdev-php/src/kdev-php-5.4.5/parser/php.g" 1
+# 147 "/chakra/desktop/kdev-php/src/kdev-php-5.5.2/parser/php.g" 1
 
     KDevelop::DUContext* ducontext;
 
@@ -456,13 +459,14 @@ struct KDEVPHPPARSER_EXPORT ClassStatementAst: public AstNode
 {
     enum { KIND = ClassStatementKind };
 
-    const KDevPG::ListNode<ClassConstantDeclarationAst *> *constsSequence;
     ClassVariableDeclarationAst *variable;
     OptionalModifiersAst *modifiers;
+    PropertyTypeAst *propertyType;
     SemiReservedIdentifierAst *methodName;
     ParameterListAst *parameters;
     ReturnTypeAst *returnType;
     MethodBodyAst *methodBody;
+    const KDevPG::ListNode<ClassConstantDeclarationAst *> *constsSequence;
     const KDevPG::ListNode<NamespacedIdentifierAst *> *traitsSequence;
     TraitAliasDeclarationAst *imports;
 };
@@ -965,6 +969,23 @@ struct KDEVPHPPARSER_EXPORT PrintExpressionAst: public AstNode
     AssignmentExpressionAst *expression;
 };
 
+struct KDEVPHPPARSER_EXPORT PropertyTypeAst: public AstNode
+{
+    enum { KIND = PropertyTypeKind };
+
+    qint64 isNullable;
+    PropertyTypeHintAst *typehint;
+};
+
+struct KDEVPHPPARSER_EXPORT PropertyTypeHintAst: public AstNode
+{
+    enum { KIND = PropertyTypeHintKind };
+
+    int callableType;
+    NamespacedIdentifierAst *genericType;
+    qint64 arrayType;
+};
+
 struct KDEVPHPPARSER_EXPORT RelationalExpressionAst: public AstNode
 {
     enum { KIND = RelationalExpressionKind };
@@ -1093,7 +1114,7 @@ struct KDEVPHPPARSER_EXPORT StatementAst: public AstNode
     const KDevPG::ListNode<ExprAst *> *echoExprsSequence;
     ExprAst *throwExpr;
     const KDevPG::ListNode<ConstantDeclarationAst *> *constsSequence;
-    const KDevPG::ListNode<UseNamespaceAst *> *useNamespaceSequence;
+    UseStatementAst *useStatement;
     qint64 gotoLabel;
     qint64 gotoTarget;
 };
@@ -1237,6 +1258,15 @@ struct KDEVPHPPARSER_EXPORT UseNamespaceAst: public AstNode
     IdentifierAst *aliasIdentifier;
 };
 
+struct KDEVPHPPARSER_EXPORT UseStatementAst: public AstNode
+{
+    enum { KIND = UseStatementKind };
+
+    qint64 useFunction;
+    qint64 useConst;
+    const KDevPG::ListNode<UseNamespaceAst *> *useNamespaceSequence;
+};
+
 struct KDEVPHPPARSER_EXPORT VarExpressionAst: public AstNode
 {
     enum { KIND = VarExpressionKind };
