@@ -6,7 +6,7 @@
 
 #include "parserexport.h"
 
-# 58 "/builds/chakra/packages/desktop/kdev-php/src/kdev-php-5.4.5/parser/php.g" 1
+# 58 "/chakra/desktop/kdev-php/src/kdev-php-5.5.2/parser/php.g" 1
 
 
 #include <QtCore/QRegularExpression>
